//
//  BezelWindow.m
//  StarPerformer
//
//  Created by Jonathan del Strother on 20/06/2006.
//  Copyright 2006 Steel Skies. All rights reserved.
//
//  Licensed under a Creative Commons Attribution-NonCommercial license
//  http://creativecommons.org/licenses/by-nc/2.5/

#import "BezelWindow.h"


#define WIDTH 212
#define HEIGHT 206

@interface SSBezelWindow (private)
-(id)initOnScreen:(NSScreen*)screen;
@end

@implementation SSBezelWindow

static SSBezelWindow* sharedBezel = nil;

NSRect rectForScreen(NSScreen* screen)
{
	NSRect screenRect = [screen frame];
	return NSMakeRect(screenRect.origin.x + screenRect.size.width/2 - WIDTH/2,
								   screenRect.origin.y + 140,	//BezelUIServices windows are 140px from the bottom of the screen.
								   WIDTH, HEIGHT);	
}


+(id)sharedBezel
{
	if(!sharedBezel)
		sharedBezel = [[SSBezelWindow alloc] initOnScreen:[NSScreen mainScreen]];
		
//	if ([sharedBezel screen] != [NSScreen mainScreen])
	[sharedBezel setFrame:rectForScreen([NSScreen mainScreen]) display:YES];

	return sharedBezel;
}

-(id)initOnScreen:(NSScreen*)screen
{
	NSRect windowRect = rectForScreen(screen);

	if (!(self = [super initWithContentRect:windowRect styleMask:NSBorderlessWindowMask backing:NSBackingStoreBuffered  defer:NO]))
		return nil;
	
	
	[self setOpaque:NO];
	[self setBackgroundColor:[NSColor colorWithDeviceRed:0 green:0 blue:0.0 alpha:0.0]];
	[self setAlphaValue:0.0];
	[self setLevel:NSScreenSaverWindowLevel];

	imageView = [[NSImageView alloc] init];
	[self setContentView:imageView];

	timer = [[NSTimer scheduledTimerWithTimeInterval:0.04 target:self selector:@selector(updateBezel:) userInfo:nil repeats:YES] retain];

	return self;
}


-(void)setImage:(NSImage*)image
{
	[imageView setImage:image];
}

-(void)setDelegate:(id)del
{
	delegate = del;
}
-(void)setFadeTime:(NSDate*)newTime
{
	[fadeTime release];
	fadeTime = [newTime retain];
	[self orderFront:self];
}

-(void)dealloc
{
	[fadeTime release];
	[timer invalidate];
	[timer release];
	[imageView release];
	[super dealloc];
}


-(void)updateBezel:(NSTimer*)sender
{
	float timeToFade = [fadeTime timeIntervalSinceNow];
	float currentAlpha = [self alphaValue];
	if ((timeToFade < 1)&&(currentAlpha > 0.00))
	{
		currentAlpha -= 0.08;
		[self setAlphaValue:currentAlpha];
		if (currentAlpha < 0.04)
		{
			[self orderOut:self];
		}
	}
	else if (currentAlpha < 0.96)
	{
		currentAlpha += 0.15;
		[self setAlphaValue:currentAlpha];
	}
}

@end