//
//  NSWindow+ForceKey.h
//  StarPerformer
//
//  Created by Jonathan del Strother on 16/06/2006.
//  Copyright 2006 Steel Skies. All rights reserved.
//
//  Licensed under a Creative Commons Attribution-NonCommercial license
//  http://creativecommons.org/licenses/by-nc/2.5/

#import <Cocoa/Cocoa.h>



//Bunch of classes ripped out of Safari's classdump - needed for our BrowserWindow replacement
@interface ButtonPlus : NSButton
{
    unsigned int _lastMouseDownModifierFlags;
}

- (void)mouseDown:(id)fp8;
- (unsigned int)lastMouseDownModifierFlags;
- (void)rightMouseDown:(id)fp8;

@end



@interface RolloverTrackingButton : ButtonPlus
{
    BOOL _mouseOver;
    BOOL _redrawOnMouseEnteredAndExited;
    BOOL _trackingRectUpdatePending;
    int _trackingRectTag;
    id delegate;
}

- (void)initTrackingRect;
- (id)initWithFrame:(struct _NSRect)fp8;
- (void)setFrameOrigin:(struct _NSPoint)fp8;
- (void)setFrameSize:(struct _NSSize)fp8;
- (void)setFrameRotation:(float)fp8;
- (void)setBoundsOrigin:(struct _NSPoint)fp8;
- (void)setBoundsSize:(struct _NSSize)fp8;
- (void)setBoundsRotation:(float)fp8;
- (void)awakeFromNib;
- (void)dealloc;
- (BOOL)mouseIsOver;
- (void)mouseEnteredOrExited:(BOOL)fp8;
- (void)setRedrawOnMouseEnteredAndExited:(BOOL)fp8;
- (BOOL)redrawOnMouseEnteredAndExited;
- (void)updateMouseIsOver:(int)fp8;
- (void)removeTrackingRect;
- (void)updateTrackingRect;
- (void)_updateTrackingRectSoon;
- (void)viewWillMoveToWindow:(id)fp8;
- (void)viewDidMoveToWindow;
- (void)mouseEntered:(id)fp8;
- (void)mouseExited:(id)fp8;
- (void)rightMouseDown:(id)fp8;
- (void)setDelegate:(id)fp8;
- (id)delegate;

@end

@interface RolloverImageButton : RolloverTrackingButton
{
    NSImage *_rolloverImage;
}

- (void)_setAttributes;
- (id)initWithFrame:(struct _NSRect)fp8;
- (void)awakeFromNib;
- (void)dealloc;
- (void)setRolloverImage:(id)fp8;
- (id)rolloverImage;
- (void)drawRect:(struct _NSRect)fp8;

@end

@interface TitleBarButton : NSView
{
    NSString *_title;
    NSTextFieldCell *_titleCell;
}

- (id)initWithFrame:(struct _NSRect)fp8;
- (void)dealloc;
- (struct _NSRect)titleRect;
- (struct _NSRect)titleRectInWindow;
- (void)drawRect:(struct _NSRect)fp8;
- (BOOL)isFlipped;
- (void)doNothing:(id)fp8;
- (void)goToMenuItemURL:(id)fp8;
- (void)showPathRepresentingPopUpMenu;
- (id)hitTest:(struct _NSPoint)fp8;
- (void)mouseDown:(id)fp8;
- (id)title;
- (void)resetNoDragRect;
- (void)updateFrame;
- (void)setFrame:(struct _NSRect)fp8;
- (void)viewDidEndLiveResize;
- (void)windowDidEndSheet:(id)fp8;
- (void)windowDidDeminiaturize:(id)fp8;
- (void)setTitle:(id)fp8;
- (BOOL)accessibilityIsIgnored;
- (id)accessibilityAttributeNames;
- (id)accessibilityAttributeValue:(id)fp8;
- (BOOL)accessibilityIsAttributeSettable:(id)fp8;
- (id)accessibilityActionNames;
- (id)accessibilityActionDescription:(id)fp8;
- (void)accessibilityPerformAction:(id)fp8;

@end

@interface Window : NSWindow
{
    BOOL unresizable;
    struct _NSSize savedMinContentSize;
    struct _NSSize savedMaxContentSize;
}

- (void)dealloc;
- (void)close;
- (void)becomeKeyWindow;
- (void)_setFrameAfterMove:(struct _NSRect)fp8;
- (id)findFrontmostOtherWindowOfWidth:(float)fp8;
- (struct _NSRect)adjustedFrameForCascade:(struct _NSRect)fp8 fromWindow:(id)fp24;
- (struct _NSPoint)cascadeTopLeftFromPoint:(struct _NSPoint)fp8;
- (BOOL)isResizable;
- (void)setResizable:(BOOL)fp8;
- (void)setFrame:(struct _NSRect)fp8 display:(BOOL)fp24;
- (BOOL)validateUserInterfaceItem:(id)fp8;

@end

@interface BrowserWindow : Window
{
    BOOL logAfterNextRedisplay;
    BOOL ignoresOrderFront;
    TitleBarButton *_titleBarButton;
    RolloverImageButton *_securityButton;
    NSString *_title;
}

+ (id)_lockImage;
- (void)_setTitleBarButton;
- (void)_positionSecurityButton;
- (void)_setUpSecurityButton;
- (void)awakeFromNib;
- (void)sendEvent:(id)fp8;
- (void)keyDown:(id)fp8;
- (void)updateCGSWindowTitle;
- (void)_commonAwake;
- (struct _NSRect)_adjustedFrameForSaving:(struct _NSRect)fp8;
- (struct _NSRect)adjustedFrameForCascade:(struct _NSRect)fp8 fromWindow:(id)fp24;
- (BOOL)performKeyEquivalent:(id)fp8;
- (void)logFirstPageLoadedAfterNextRedisplay;
- (void)logFirstPageLoaded;
- (void)display;
- (void)displayIfNeeded;
- (void)updateTitle;
- (void)close;
- (void)setTitle:(id)fp8;
- (id)title;
- (void)certificateSheetDidEnd:(id)fp8 returnCode:(int)fp12 contextInfo:(void *)fp16;
- (void)_securityButtonClicked:(id)fp8;
- (void)setIsShowingSecurityButton:(BOOL)fp8;
- (BOOL)isShowingSecurityButton;
- (void)dealloc;
- (void)setDelegate:(id)fp8;
- (void)setWindowController:(id)fp8;
- (void)flushWindow;
- (BOOL)ignoresOrderFront;
- (void)setIgnoresOrderFront:(BOOL)fp8;
- (void)orderFront:(id)fp8;
- (void)_handleFocusToolbarHotKey:(id)fp8;
- (BOOL)makeFirstResponder:(id)fp8;
- (id)accessibilityHitTest:(struct _NSPoint)fp8;
- (id)accessibilityAttributeValue:(id)fp8;

@end

@interface SSMagicalWindow : BrowserWindow

-(BOOL)forceKey;
-(void)setForceKey:(BOOL)value;

@end
