//
//  NSWindow+ForceKey.m
//  StarPerformer
//
//  Created by Jonathan del Strother on 16/06/2006.
//  Copyright 2006 Steel Skies. All rights reserved.
//
//  Licensed under a Creative Commons Attribution-NonCommercial license
//  http://creativecommons.org/licenses/by-nc/2.5/

#import "NSWindow+ForceKey.h"
#import "BezelWindow.h"

@implementation SSMagicalWindow

static NSMutableDictionary* instanceVars = nil;
static NSBundle* ourBundle = nil;
static NSImage* keyImage = nil;
static NSImage* unkeyImage = nil;
+(void)initialize
{
	if (!instanceVars)
	{
		instanceVars = [[NSMutableDictionary alloc] init];
		
		ourBundle = [NSBundle bundleForClass:[self class]];
		keyImage = [[NSImage alloc] initWithContentsOfFile:[ourBundle pathForImageResource:@"Key.png"]];
		unkeyImage = [[NSImage alloc] initWithContentsOfFile:[ourBundle pathForImageResource:@"Unkey.png"]];
	}
}

-(NSMutableDictionary*)vars
{
	NSMutableDictionary* vars = [instanceVars objectForKey:self];
	if (!vars)
	{
		NSMutableDictionary* newVars = [NSMutableDictionary dictionaryWithObjectsAndKeys:
				[NSNumber numberWithBool:NO],@"forceKey", nil];
		[instanceVars setObject:newVars forKey:self];
	}
	return vars;
}

-(NSString*)realTitle
{
	NSString* realTitle = [[self vars] objectForKey:@"realTitle"];
	if (!realTitle)
		realTitle = [self title];
	return realTitle;
}

-(void)storeRealTitle:(NSString*)realTitle
{
	[[self vars] setObject:realTitle forKey:@"realTitle"];
}

-(BOOL)forceKey
{
	return [[[self vars] objectForKey:@"forceKey"] boolValue];
}

-(void)setForceKey:(BOOL)value
{
	[[self vars] setObject:[NSNumber numberWithBool:value] forKey:@"forceKey"];
	
	[[SSBezelWindow sharedBezel] setFadeTime:[NSDate dateWithTimeIntervalSinceNow:2.5]];
	[[SSBezelWindow sharedBezel] setImage:value?keyImage : unkeyImage];

	[self setTitle:[self realTitle]];
}




-(BOOL)isKeyWindow
{
	BOOL val = [self forceKey] || [super isKeyWindow];
	return val;
}


-(void)setTitle:(NSString*)title
{
	[self storeRealTitle:title];
	
	if ([self forceKey])
	{
		unichar uStar = 0x272D;
		NSString* star = [NSString stringWithCharacters:&uStar length:1];
		title = [NSString stringWithFormat:@"%@ %@ %@", star, title, star];
	}
	
	[super setTitle:title];
}


-(void)dealloc
{
	[[self vars] removeObjectForKey:self];
	[super dealloc];
}

@end
