//
//  StarPerformerController.m
//  StarPerformer
//
//  Created by Jonathan del Strother on 26/06/2006.
//  Copyright 2006 Steel Skies. All rights reserved.
//
//  Licensed under a Creative Commons Attribution-NonCommercial license
//  http://creativecommons.org/licenses/by-nc/2.5/

#import "StarPerformerController.h"
#import "NSWindow+ForceKey.h"

@implementation SSStarPerformerController

-(id)init
{
	self = [super init];
	if (!self)
		return nil;
		
	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(finishedLaunching:) name:NSApplicationDidUpdateNotification object:nil];
	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(windowBecameKey:) name:NSWindowDidBecomeKeyNotification object:nil];
	[[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(windowWillClose:) name:NSWindowWillCloseNotification object:nil];
	
	return self;
}

-(void)finishedLaunching:(NSNotification*)notification
{
	if (!starMenu)
	{
		NSMenu* fileMenu = [[[[NSApplication sharedApplication] mainMenu] itemAtIndex:1] submenu];
		if (fileMenu)	
		{
			NSArray* items = [fileMenu itemArray];
			NSMenuItem* item;
			NSEnumerator* itemEnum = [items objectEnumerator];
			while (item = [itemEnum nextObject])
			{
				if ([item action] == @selector(performClose:))
				{
					//Insert a new menu item just before the Close Window menu item.
					starMenu = [[NSMenuItem alloc] initWithTitle:@"Toggle Star Performer" action:@selector(forceKeySelected:) keyEquivalent:@""];
					[starMenu setKeyEquivalent:@"s"];
					[starMenu setKeyEquivalentModifierMask:NSControlKeyMask+NSAlternateKeyMask];
					[starMenu setTarget:self];
					[fileMenu insertItem:starMenu atIndex:[fileMenu indexOfItem:item]];
				}
			}
		}
	}
}

-(void)updateMenuTitle
{
	SSMagicalWindow* keyWindow = (SSMagicalWindow*)[[NSApplication sharedApplication] keyWindow];
	if ([keyWindow respondsToSelector:@selector(forceKey)])
		[starMenu setTitle:[keyWindow forceKey] ? @"Unmake Star Performer":@"Make Star Performer"];
}

-(void)windowBecameKey:(NSNotification*)notification
{
	menuShouldBeEnabled = YES;
	[self updateMenuTitle];
}

-(void)windowWillClose:(NSNotification*)notification
{
	menuShouldBeEnabled = NO;
}

-(void)forceKeySelected:(id)sender
{
	SSMagicalWindow* keyWindow = (SSMagicalWindow*)[[NSApplication sharedApplication] keyWindow];
	if ([keyWindow respondsToSelector:@selector(forceKey)])
	{
		[keyWindow setForceKey:![keyWindow forceKey]];
		[self updateMenuTitle];
	}
}

-(BOOL)respondsToSelector:(SEL)sel
{
	if (sel == @selector(forceKeySelected:))
		return menuShouldBeEnabled;
	else
		return [super respondsToSelector:sel];		
}

@end
